# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spice21.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import api_pb2 as google_dot_protobuf_dot_api__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import source_context_pb2 as google_dot_protobuf_dot_source__context__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import type_pb2 as google_dot_protobuf_dot_type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='spice21.proto',
  package='spice21.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rspice21.proto\x12\rspice21.proto\x1a\x19google/protobuf/any.proto\x1a\x19google/protobuf/api.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a$google/protobuf/source_context.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1agoogle/protobuf/type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x14\n\x04Node\x12\x0c\n\x04name\x18\x01 \x01(\t\"9\n\x08Resistor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\t\x12\t\n\x01n\x18\x03 \x01(\t\x12\t\n\x01g\x18\x04 \x01(\x01\":\n\tCapacitor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\t\x12\t\n\x01n\x18\x03 \x01(\t\x12\t\n\x01\x63\x18\x04 \x01(\x01\"?\n\x03Mos\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01g\x18\x02 \x01(\t\x12\t\n\x01\x64\x18\x03 \x01(\t\x12\t\n\x01s\x18\x04 \x01(\t\x12\t\n\x01\x62\x18\x05 \x01(\t\"6\n\x04Isrc\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\t\x12\t\n\x01n\x18\x03 \x01(\t\x12\n\n\x02\x64\x63\x18\x04 \x01(\x01\"C\n\x04Vsrc\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\t\x12\t\n\x01n\x18\x03 \x01(\t\x12\n\n\x02\x64\x63\x18\x04 \x01(\x01\x12\x0b\n\x03\x61\x63m\x18\x05 \x01(\x01\"\xd1\x01\n\nDiodeModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tnom\x18\x02 \x01(\x01\x12\n\n\x02is\x18\x03 \x01(\x01\x12\t\n\x01n\x18\x04 \x01(\x01\x12\n\n\x02tt\x18\x05 \x01(\x01\x12\n\n\x02vj\x18\x06 \x01(\x01\x12\t\n\x01m\x18\x07 \x01(\x01\x12\n\n\x02\x65g\x18\x08 \x01(\x01\x12\x0b\n\x03xti\x18\t \x01(\x01\x12\n\n\x02kf\x18\n \x01(\x01\x12\n\n\x02\x61\x66\x18\x0b \x01(\x01\x12\n\n\x02\x66\x63\x18\x0c \x01(\x01\x12\n\n\x02\x62v\x18\r \x01(\x01\x12\x0b\n\x03ibv\x18\x0e \x01(\x01\x12\n\n\x02rs\x18\x0f \x01(\x01\x12\x0b\n\x03\x63j0\x18\x10 \x01(\x01\"G\n\x05\x44iode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\t\x12\t\n\x01n\x18\x03 \x01(\t\x12\x0c\n\x04\x61rea\x18\x04 \x01(\x01\x12\x0c\n\x04temp\x18\x05 \x01(\x01\"\xe9\x01\n\x08Instance\x12$\n\x01r\x18\x01 \x01(\x0b\x32\x17.spice21.proto.ResistorH\x00\x12%\n\x01\x63\x18\x02 \x01(\x0b\x32\x18.spice21.proto.CapacitorH\x00\x12!\n\x03mos\x18\x03 \x01(\x0b\x32\x12.spice21.proto.MosH\x00\x12 \n\x01i\x18\x04 \x01(\x0b\x32\x13.spice21.proto.IsrcH\x00\x12 \n\x01v\x18\x05 \x01(\x0b\x32\x13.spice21.proto.VsrcH\x00\x12!\n\x01\x64\x18\x06 \x01(\x0b\x32\x14.spice21.proto.DiodeH\x00\x42\x06\n\x04\x63omp\"a\n\x07\x43ircuit\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x05\x63omps\x18\x02 \x03(\x0b\x32\x17.spice21.proto.Instance\x12 \n\x04\x64\x65\x66s\x18\x03 \x03(\x0b\x32\x12.spice21.proto.Def\"A\n\x03\x44\x65\x66\x12/\n\ndiodemodel\x18\x01 \x01(\x0b\x32\x19.spice21.proto.DiodeModelH\x00\x42\t\n\x07\x64\x65\x66ines\"\\\n\tStatement\x12\'\n\x04inst\x18\x01 \x01(\x0b\x32\x17.spice21.proto.InstanceH\x00\x12!\n\x03\x64\x65\x66\x18\x02 \x01(\x0b\x32\x12.spice21.proto.DefH\x00\x42\x03\n\x01s\"*\n\x03Sim\x12#\n\x03\x63kt\x18\x01 \x01(\x0b\x32\x16.spice21.proto.Circuitb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_api__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_source__context__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='spice21.proto.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Node.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=362,
)


_RESISTOR = _descriptor.Descriptor(
  name='Resistor',
  full_name='spice21.proto.Resistor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Resistor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='spice21.proto.Resistor.p', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='spice21.proto.Resistor.n', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='spice21.proto.Resistor.g', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=421,
)


_CAPACITOR = _descriptor.Descriptor(
  name='Capacitor',
  full_name='spice21.proto.Capacitor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Capacitor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='spice21.proto.Capacitor.p', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='spice21.proto.Capacitor.n', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='spice21.proto.Capacitor.c', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=481,
)


_MOS = _descriptor.Descriptor(
  name='Mos',
  full_name='spice21.proto.Mos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Mos.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='spice21.proto.Mos.g', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='spice21.proto.Mos.d', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='spice21.proto.Mos.s', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='spice21.proto.Mos.b', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=546,
)


_ISRC = _descriptor.Descriptor(
  name='Isrc',
  full_name='spice21.proto.Isrc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Isrc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='spice21.proto.Isrc.p', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='spice21.proto.Isrc.n', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dc', full_name='spice21.proto.Isrc.dc', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=602,
)


_VSRC = _descriptor.Descriptor(
  name='Vsrc',
  full_name='spice21.proto.Vsrc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Vsrc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='spice21.proto.Vsrc.p', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='spice21.proto.Vsrc.n', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dc', full_name='spice21.proto.Vsrc.dc', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acm', full_name='spice21.proto.Vsrc.acm', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=671,
)


_DIODEMODEL = _descriptor.Descriptor(
  name='DiodeModel',
  full_name='spice21.proto.DiodeModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.DiodeModel.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tnom', full_name='spice21.proto.DiodeModel.tnom', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is', full_name='spice21.proto.DiodeModel.is', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='spice21.proto.DiodeModel.n', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tt', full_name='spice21.proto.DiodeModel.tt', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vj', full_name='spice21.proto.DiodeModel.vj', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m', full_name='spice21.proto.DiodeModel.m', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eg', full_name='spice21.proto.DiodeModel.eg', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xti', full_name='spice21.proto.DiodeModel.xti', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kf', full_name='spice21.proto.DiodeModel.kf', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af', full_name='spice21.proto.DiodeModel.af', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fc', full_name='spice21.proto.DiodeModel.fc', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bv', full_name='spice21.proto.DiodeModel.bv', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibv', full_name='spice21.proto.DiodeModel.ibv', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rs', full_name='spice21.proto.DiodeModel.rs', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cj0', full_name='spice21.proto.DiodeModel.cj0', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=883,
)


_DIODE = _descriptor.Descriptor(
  name='Diode',
  full_name='spice21.proto.Diode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Diode.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='spice21.proto.Diode.p', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='spice21.proto.Diode.n', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area', full_name='spice21.proto.Diode.area', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp', full_name='spice21.proto.Diode.temp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=956,
)


_INSTANCE = _descriptor.Descriptor(
  name='Instance',
  full_name='spice21.proto.Instance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='spice21.proto.Instance.r', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='spice21.proto.Instance.c', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mos', full_name='spice21.proto.Instance.mos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i', full_name='spice21.proto.Instance.i', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='spice21.proto.Instance.v', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='spice21.proto.Instance.d', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='comp', full_name='spice21.proto.Instance.comp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=959,
  serialized_end=1192,
)


_CIRCUIT = _descriptor.Descriptor(
  name='Circuit',
  full_name='spice21.proto.Circuit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='spice21.proto.Circuit.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comps', full_name='spice21.proto.Circuit.comps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defs', full_name='spice21.proto.Circuit.defs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1291,
)


_DEF = _descriptor.Descriptor(
  name='Def',
  full_name='spice21.proto.Def',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diodemodel', full_name='spice21.proto.Def.diodemodel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='defines', full_name='spice21.proto.Def.defines',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1293,
  serialized_end=1358,
)


_STATEMENT = _descriptor.Descriptor(
  name='Statement',
  full_name='spice21.proto.Statement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inst', full_name='spice21.proto.Statement.inst', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='def', full_name='spice21.proto.Statement.def', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='s', full_name='spice21.proto.Statement.s',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1360,
  serialized_end=1452,
)


_SIM = _descriptor.Descriptor(
  name='Sim',
  full_name='spice21.proto.Sim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ckt', full_name='spice21.proto.Sim.ckt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1454,
  serialized_end=1496,
)

_INSTANCE.fields_by_name['r'].message_type = _RESISTOR
_INSTANCE.fields_by_name['c'].message_type = _CAPACITOR
_INSTANCE.fields_by_name['mos'].message_type = _MOS
_INSTANCE.fields_by_name['i'].message_type = _ISRC
_INSTANCE.fields_by_name['v'].message_type = _VSRC
_INSTANCE.fields_by_name['d'].message_type = _DIODE
_INSTANCE.oneofs_by_name['comp'].fields.append(
  _INSTANCE.fields_by_name['r'])
_INSTANCE.fields_by_name['r'].containing_oneof = _INSTANCE.oneofs_by_name['comp']
_INSTANCE.oneofs_by_name['comp'].fields.append(
  _INSTANCE.fields_by_name['c'])
_INSTANCE.fields_by_name['c'].containing_oneof = _INSTANCE.oneofs_by_name['comp']
_INSTANCE.oneofs_by_name['comp'].fields.append(
  _INSTANCE.fields_by_name['mos'])
_INSTANCE.fields_by_name['mos'].containing_oneof = _INSTANCE.oneofs_by_name['comp']
_INSTANCE.oneofs_by_name['comp'].fields.append(
  _INSTANCE.fields_by_name['i'])
_INSTANCE.fields_by_name['i'].containing_oneof = _INSTANCE.oneofs_by_name['comp']
_INSTANCE.oneofs_by_name['comp'].fields.append(
  _INSTANCE.fields_by_name['v'])
_INSTANCE.fields_by_name['v'].containing_oneof = _INSTANCE.oneofs_by_name['comp']
_INSTANCE.oneofs_by_name['comp'].fields.append(
  _INSTANCE.fields_by_name['d'])
_INSTANCE.fields_by_name['d'].containing_oneof = _INSTANCE.oneofs_by_name['comp']
_CIRCUIT.fields_by_name['comps'].message_type = _INSTANCE
_CIRCUIT.fields_by_name['defs'].message_type = _DEF
_DEF.fields_by_name['diodemodel'].message_type = _DIODEMODEL
_DEF.oneofs_by_name['defines'].fields.append(
  _DEF.fields_by_name['diodemodel'])
_DEF.fields_by_name['diodemodel'].containing_oneof = _DEF.oneofs_by_name['defines']
_STATEMENT.fields_by_name['inst'].message_type = _INSTANCE
_STATEMENT.fields_by_name['def'].message_type = _DEF
_STATEMENT.oneofs_by_name['s'].fields.append(
  _STATEMENT.fields_by_name['inst'])
_STATEMENT.fields_by_name['inst'].containing_oneof = _STATEMENT.oneofs_by_name['s']
_STATEMENT.oneofs_by_name['s'].fields.append(
  _STATEMENT.fields_by_name['def'])
_STATEMENT.fields_by_name['def'].containing_oneof = _STATEMENT.oneofs_by_name['s']
_SIM.fields_by_name['ckt'].message_type = _CIRCUIT
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Resistor'] = _RESISTOR
DESCRIPTOR.message_types_by_name['Capacitor'] = _CAPACITOR
DESCRIPTOR.message_types_by_name['Mos'] = _MOS
DESCRIPTOR.message_types_by_name['Isrc'] = _ISRC
DESCRIPTOR.message_types_by_name['Vsrc'] = _VSRC
DESCRIPTOR.message_types_by_name['DiodeModel'] = _DIODEMODEL
DESCRIPTOR.message_types_by_name['Diode'] = _DIODE
DESCRIPTOR.message_types_by_name['Instance'] = _INSTANCE
DESCRIPTOR.message_types_by_name['Circuit'] = _CIRCUIT
DESCRIPTOR.message_types_by_name['Def'] = _DEF
DESCRIPTOR.message_types_by_name['Statement'] = _STATEMENT
DESCRIPTOR.message_types_by_name['Sim'] = _SIM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Node)
  })
_sym_db.RegisterMessage(Node)

Resistor = _reflection.GeneratedProtocolMessageType('Resistor', (_message.Message,), {
  'DESCRIPTOR' : _RESISTOR,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Resistor)
  })
_sym_db.RegisterMessage(Resistor)

Capacitor = _reflection.GeneratedProtocolMessageType('Capacitor', (_message.Message,), {
  'DESCRIPTOR' : _CAPACITOR,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Capacitor)
  })
_sym_db.RegisterMessage(Capacitor)

Mos = _reflection.GeneratedProtocolMessageType('Mos', (_message.Message,), {
  'DESCRIPTOR' : _MOS,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Mos)
  })
_sym_db.RegisterMessage(Mos)

Isrc = _reflection.GeneratedProtocolMessageType('Isrc', (_message.Message,), {
  'DESCRIPTOR' : _ISRC,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Isrc)
  })
_sym_db.RegisterMessage(Isrc)

Vsrc = _reflection.GeneratedProtocolMessageType('Vsrc', (_message.Message,), {
  'DESCRIPTOR' : _VSRC,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Vsrc)
  })
_sym_db.RegisterMessage(Vsrc)

DiodeModel = _reflection.GeneratedProtocolMessageType('DiodeModel', (_message.Message,), {
  'DESCRIPTOR' : _DIODEMODEL,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.DiodeModel)
  })
_sym_db.RegisterMessage(DiodeModel)

Diode = _reflection.GeneratedProtocolMessageType('Diode', (_message.Message,), {
  'DESCRIPTOR' : _DIODE,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Diode)
  })
_sym_db.RegisterMessage(Diode)

Instance = _reflection.GeneratedProtocolMessageType('Instance', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCE,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Instance)
  })
_sym_db.RegisterMessage(Instance)

Circuit = _reflection.GeneratedProtocolMessageType('Circuit', (_message.Message,), {
  'DESCRIPTOR' : _CIRCUIT,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Circuit)
  })
_sym_db.RegisterMessage(Circuit)

Def = _reflection.GeneratedProtocolMessageType('Def', (_message.Message,), {
  'DESCRIPTOR' : _DEF,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Def)
  })
_sym_db.RegisterMessage(Def)

Statement = _reflection.GeneratedProtocolMessageType('Statement', (_message.Message,), {
  'DESCRIPTOR' : _STATEMENT,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Statement)
  })
_sym_db.RegisterMessage(Statement)

Sim = _reflection.GeneratedProtocolMessageType('Sim', (_message.Message,), {
  'DESCRIPTOR' : _SIM,
  '__module__' : 'spice21_pb2'
  # @@protoc_insertion_point(class_scope:spice21.proto.Sim)
  })
_sym_db.RegisterMessage(Sim)


# @@protoc_insertion_point(module_scope)



from spice21py import *


def test_health():
    """ Test the core library is "there". """
    a = health()
    assert a == 'alive'
    print(f"spice21 core is {a}")


def test_dcop1():
    c = circuit([
        Diode(p="1"),
        Resistor(p="1", g=1e3),
        Capacitor(p="1"),
        Isrc(p="1", dc=1.0),
    ])
    print(dcop(c))


def test_dcop2():
    for v in (5, 6, 7, 8):
        c = circuit(Vsrc(name='vb', dc=0.1 * v, p='a'), Diode(p='a'))
        print(dcop(c))



""" 
Spice21 Python 
"""
from typing import List, Union, Any
# Import and rename the protobuf-generated content
from . import protos
from .protos import Capacitor, Resistor, Diode, Mos, Isrc, Vsrc
# Import from the core Rust interface
from .spice21py import health


def dcop(ckt: protos.Circuit) -> List[float]:
    """ DC Operating Point """
    from .spice21py import _dcop
    enc = ckt.SerializeToString()
    return _dcop(enc)


def tran(ckt: protos.Circuit) -> List[List[float]]:
    """ Transient Analysis """
    from .spice21py import _tran
    enc = ckt.SerializeToString()
    return _tran(enc)


def instance(comp) -> protos.Instance:
    """ Create an Instance from Component `comp`.
    Raises a TypeError if `comp` is not a Component or Instance. """
    from .protos import Instance
    if isinstance(comp, Instance):
        return comp
    elif isinstance(comp, Diode):
        return Instance(d=comp)
    elif isinstance(comp, Capacitor):
        return Instance(c=comp)
    elif isinstance(comp, Resistor):
        return Instance(r=comp)
    elif isinstance(comp, Mos):
        return Instance(mos=comp)
    elif isinstance(comp, Isrc):
        return Instance(i=comp)
    elif isinstance(comp, Vsrc):
        return Instance(v=comp)
    else:
        raise TypeError(f"Invalid Circuit Component {type(comp)}")


def circuit(*args) -> protos.Circuit:
    """ Circuit generation from component list *args """
    from .protos import Circuit, Instance

    if len(args) == 1 and isinstance(args[0], (list, tuple)):
        comps = args[0]
    else:
        comps = args

    c = Circuit()
    for comp in comps:
        c.comps.append(instance(comp))

    return c
